<?php
/**
 * @package bibly
 * @version 0.4
 */
/*
Plugin Name: bib.ly - Bible reference shortener
Plugin URI: http://bib.ly/
Description: A Bible reference shortener that allows visitors to choose their favorite website (YouVersion, BibleGateway) in which to view the passage.
Author: John Dyer
Version: 0.4
Author URI: http://j.hn/
License: GPLv3, MIT
*/

/* Runs when plugin is activated */
register_activation_hook(__FILE__,'bibly_install'); 

function bibly_install() {
	add_option('bibly_use_debug', 'false');
}

// create custom plugin settings menu
add_action('admin_menu', 'bibly_create_menu');

function bibly_create_menu() {

	//create new top-level menu
	add_options_page('bib.ly Settings', 'bib.ly Settings', 'administrator', __FILE__, 'bibly_settings_page');

	//call register settings function
	add_action( 'admin_init', 'bibly_register_settings' );
}


function bibly_register_settings() {
	//register our settings
	register_setting( 'bibly_settings', 'bibly_use_debug' );
}

function bibly_settings_page() {
?>
<div class="wrap">
<h2>bib.ly Options</h2>

<p>See <a href="http://bib.ly/">bib.ly</a> for more examples.</p>

<form method="post" action="options.php">
<?php wp_nonce_field('update-options'); ?>


	<h3 class="title"><span>Main Settings</span></h3>
		
	<table  class="form-table">
		<tr valign="top">
			<th scope="row">
				<label for="bibly_use_debug">Use Debug Scripts</label>
			</th>
			<td >
				<input name="bibly_use_debug" type="checkbox" id="bibly_use_debug" value="true" <?php echo (get_option('bibly_use_debug') == 'true') ? ' checked="checked"' : ''; ?> />
			</td>
		</tr>	
	</table>

	<input type="hidden" name="action" value="update" />
	<input type="hidden" name="page_options" value="bibly_use_debug" />

	<p>
		<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
	</p>

</div>

</form>
</div>
<?php
}

/* Runs on plugin deactivation*/
register_deactivation_hook( __FILE__, 'bibly_remove' );
function bibly_remove() {
	delete_option('bibly_use_debug');
}

function bibly_add_header(){
	
	$use_debug = get_option('bibly_use_debug');
		
	if ($use_debug ) {
		echo '<link rel="stylesheet" href="http://code.bib.ly/bibly.css" type="text/css"  />';
		echo '<script src="http://code.bib.ly/bibly.js" type="text/javascript"></script>';

	} else {
		echo '<link rel="stylesheet" href="http://code.bib.ly/bibly.min.css" type="text/css"  />';
		echo '<script src="http://code.bib.ly/bibly.min.js" type="text/javascript"></script>';
	}
}

add_action('wp_head','bibly_add_header');

?>
